==> sonar-iac-docker-1.12.0.3222-sources.jar: org/sonar/iac/docker/tree/impl/EnvInstructionImpl.java <==
/*
 * SonarQube IaC Plugin
 * Copyright (C) 2021-2023 SonarSource SA
 * mailto:info AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.iac.docker.tree.impl;

import java.util.ArrayList;
import java.util.List;
import org.sonar.iac.common.api.tree.Tree;
import org.sonar.iac.docker.tree.api.EnvInstruction;
import org.sonar.iac.docker.tree.api.KeyValuePair;
import org.sonar.iac.docker.tree.api.SyntaxToken;

public class EnvInstructionImpl extends InstructionImpl implements EnvInstruction {
  private final List<KeyValuePair> keyValuePairs;

  public EnvInstructionImpl(SyntaxToken keyword, List<KeyValuePair> keyValuePairs) {
    super(keyword);
    this.keyValuePairs = keyValuePairs;
  }

  @Override
  public List<KeyValuePair> environmentVariables() {
    return keyValuePairs;
  }

  @Override
  public List<Tree> children() {
    List<Tree> children = new ArrayList<>();
    children.add(keyword);
    for (KeyValuePair keyValuePair : keyValuePairs) {
      children.addAll(keyValuePair.children());
    }
    return children;
  }

  @Override
  public Kind getKind() {
    return Kind.ENV;
  }
}

==> sonar-iac-docker-1.22.0.7057-sources.jar: org/sonar/iac/docker/tree/impl/EnvInstructionImpl.java <==
/*
 * SonarQube IaC Plugin
 * Copyright (C) 2021-2023 SonarSource SA
 * mailto:info AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.iac.docker.tree.impl;

import java.util.ArrayList;
import java.util.List;
import org.sonar.iac.common.api.tree.Tree;
import org.sonar.iac.docker.tree.api.EnvInstruction;
import org.sonar.iac.docker.tree.api.KeyValuePair;
import org.sonar.iac.docker.tree.api.SyntaxToken;

public class EnvInstructionImpl extends InstructionImpl implements EnvInstruction {
  private final List<KeyValuePair> keyValuePairs;

  public EnvInstructionImpl(SyntaxToken keyword, List<KeyValuePair> keyValuePairs) {
    super(keyword);
    this.keyValuePairs = keyValuePairs;
  }

  @Override
  public List<KeyValuePair> environmentVariables() {
    return keyValuePairs;
  }

  @Override
  public List<Tree> children() {
    List<Tree> children = new ArrayList<>();
    children.add(keyword);
    children.addAll(keyValuePairs);
    return children;
  }

  @Override
  public Kind getKind() {
    return Kind.ENV;
  }
}
